@@ -9,6 +9,7 @@ import glob
 import json
 import copy
 from pathlib import Path
+from typing import Dict
 import jsonschema
 import cfnlint.decode.cfn_yaml
 from cfnlint.version import __version__
@@ -43,7 +44,7 @@ class ConfigFileArgs(object):
         Config File arguments.
         Parses .cfnlintrc OR .cfnlintrc.yaml OR .cfnlintrc.yml in the Home and Project folder.
     """
-    file_args = {}
+    file_args: Dict = {}
     __user_config_file = None
     __project_config_file = None
     __custom_config_file = None
@@ -283,7 +284,7 @@ class RuleConfigurationAction(argparse.Action):
 
 class CliArgs(object):
     """ Base Args class"""
-    cli_args = {}
+    cli_args: Dict = {}
 
     def __init__(self, cli_args):
         self.parser = self.create_parser()
@@ -427,6 +428,10 @@ class CliArgs(object):
             '--merge-configs', default=False, action='store_true',
             help='Merges lists between configuration layers'
         )
+        advanced.add_argument(
+            '--force', help=argparse.SUPPRESS,
+            action='store_true'
+        )
 
         return parser
 
@@ -667,3 +672,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
     @property
     def merge_configs(self):
         return self._get_argument_value('merge_configs', True, True)
+
+    @property
+    def force(self):
+        return self._get_argument_value('force', False, False)
