@@ -2,12 +2,12 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
+from ast import Call
 import logging
-try:
-    from json.decoder import JSONDecodeError
-except ImportError:
-    JSONDecodeError = ValueError
-from yaml.parser import ParserError, ScannerError
+from typing import Tuple, List, Union, Callable, Optional
+from json.decoder import JSONDecodeError
+from yaml.parser import ParserError
+from yaml.scanner import ScannerError
 from yaml import YAMLError
 from cfnlint.decode import cfn_yaml, cfn_json
 from cfnlint.rules import Match, ParseError
@@ -15,16 +15,18 @@ from cfnlint.rules import Match, ParseError
 
 LOGGER = logging.getLogger(__name__)
 
+Matches = List[Match]
+Decode = Tuple[Union[str, None], Matches]
 
-def decode_str(s):
+def decode_str(s: str) -> Decode:
     """Decode the string s into an object."""
     return _decode(cfn_yaml.loads, cfn_json.loads, s, None)
 
-def decode(filename):
+def decode(filename: str) -> Decode:
     """Decode filename into an object."""
     return _decode(cfn_yaml.load, cfn_json.load, filename, filename)
 
-def _decode(yaml_f, json_f, payload, filename):
+def _decode(yaml_f: Callable, json_f: Callable, payload: str, filename: Optional[str]) -> Decode:
     """Decode payload using yaml_f and json_f, using filename for log output."""
     template = None
     matches = []
@@ -59,19 +61,19 @@ def _decode(yaml_f, json_f, payload, filename):
     except ParserError as err:
         matches = [create_match_yaml_parser_error(err, filename)]
     except ScannerError as err:
-        if err.problem in [
+        if err.problem and (err.problem in [
                 'found character \'\\t\' that cannot start any token',
                 'found unknown escape character'] or err.problem.startswith(
-                    'found unknown escape character'):
+                    'found unknown escape character')):
             try:
                 template = json_f(payload)
-            except cfn_json.JSONDecodeError as json_err:
-                for e in json_err.matches:
-                    e.filename = filename
-                matches = json_err.matches
+            except cfn_json.JSONDecodeError as json_errs:
+                for json_err in json_errs.matches:
+                    json_err.filename = filename
+                matches = json_errs.matches
             except JSONDecodeError as json_err:
-                if hasattr(json_err, 'message'):
-                    if json_err.message == 'No JSON object could be decoded':  # pylint: disable=no-member
+                if hasattr(json_err, 'msg'):
+                    if json_err.msg == 'No JSON object could be decoded':  # pylint: disable=no-member
                         matches = [create_match_yaml_parser_error(err, filename)]
                     else:
                         matches = [create_match_json_parser_error(json_err, filename)]
