@@ -10,7 +10,7 @@ class Ref(CloudFormationLintRule):
     """Check if Ref value is a string"""
     id = 'E1020'
     shortdesc = 'Ref validation of value'
-    description = 'Making sure the Ref has a value of String (no other functions are supported)'
+    description = 'Making sure the Ref has a String value (no other functions are supported)'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-ref.html'
     tags = ['functions', 'ref']
 
